@@ -162,7 +162,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -178,27 +178,27 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_apigateway
-import aws_cdk.aws_cloudfront
-import aws_cdk.aws_s3
-import constructs
+import aws_cdk.aws_apigateway as _aws_cdk_aws_apigateway_ceddda9d
+import aws_cdk.aws_cloudfront as _aws_cdk_aws_cloudfront_ceddda9d
+import aws_cdk.aws_s3 as _aws_cdk_aws_s3_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class CloudFrontToApiGateway(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-cloudfront-apigateway.CloudFrontToApiGateway",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
-        existing_api_gateway_obj: aws_cdk.aws_apigateway.RestApi,
+        existing_api_gateway_obj: _aws_cdk_aws_apigateway_ceddda9d.RestApi,
         cloud_front_distribution_props: typing.Any = None,
-        cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        cloud_front_logging_bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
         insert_http_security_headers: typing.Optional[builtins.bool] = None,
-        response_headers_policy_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps, typing.Dict[str, typing.Any]]] = None,
+        response_headers_policy_props: typing.Optional[typing.Union[_aws_cdk_aws_cloudfront_ceddda9d.ResponseHeadersPolicyProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -214,18 +214,7 @@ class CloudFrontToApiGateway(
         :summary: Constructs a new instance of the CloudFrontToApiGateway class.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                existing_api_gateway_obj: aws_cdk.aws_apigateway.RestApi,
-                cloud_front_distribution_props: typing.Any = None,
-                cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                insert_http_security_headers: typing.Optional[builtins.bool] = None,
-                response_headers_policy_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__8b39051c9d03e4d1bc82ea6c294d254a848b0b34ee4e5d9d8323f095a78312d0)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CloudFrontToApiGatewayProps(
@@ -240,23 +229,29 @@ class CloudFrontToApiGateway(
 
     @builtins.property
     @jsii.member(jsii_name="apiGateway")
-    def api_gateway(self) -> aws_cdk.aws_apigateway.RestApi:
-        return typing.cast(aws_cdk.aws_apigateway.RestApi, jsii.get(self, "apiGateway"))
+    def api_gateway(self) -> _aws_cdk_aws_apigateway_ceddda9d.RestApi:
+        return typing.cast(_aws_cdk_aws_apigateway_ceddda9d.RestApi, jsii.get(self, "apiGateway"))
 
     @builtins.property
     @jsii.member(jsii_name="cloudFrontWebDistribution")
-    def cloud_front_web_distribution(self) -> aws_cdk.aws_cloudfront.Distribution:
-        return typing.cast(aws_cdk.aws_cloudfront.Distribution, jsii.get(self, "cloudFrontWebDistribution"))
+    def cloud_front_web_distribution(
+        self,
+    ) -> _aws_cdk_aws_cloudfront_ceddda9d.Distribution:
+        return typing.cast(_aws_cdk_aws_cloudfront_ceddda9d.Distribution, jsii.get(self, "cloudFrontWebDistribution"))
 
     @builtins.property
     @jsii.member(jsii_name="cloudFrontFunction")
-    def cloud_front_function(self) -> typing.Optional[aws_cdk.aws_cloudfront.Function]:
-        return typing.cast(typing.Optional[aws_cdk.aws_cloudfront.Function], jsii.get(self, "cloudFrontFunction"))
+    def cloud_front_function(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_cloudfront_ceddda9d.Function]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_cloudfront_ceddda9d.Function], jsii.get(self, "cloudFrontFunction"))
 
     @builtins.property
     @jsii.member(jsii_name="cloudFrontLoggingBucket")
-    def cloud_front_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "cloudFrontLoggingBucket"))
+    def cloud_front_logging_bucket(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.Bucket]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.Bucket], jsii.get(self, "cloudFrontLoggingBucket"))
 
 
 @jsii.data_type(
@@ -274,11 +269,11 @@ class CloudFrontToApiGatewayProps:
     def __init__(
         self,
         *,
-        existing_api_gateway_obj: aws_cdk.aws_apigateway.RestApi,
+        existing_api_gateway_obj: _aws_cdk_aws_apigateway_ceddda9d.RestApi,
         cloud_front_distribution_props: typing.Any = None,
-        cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        cloud_front_logging_bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
         insert_http_security_headers: typing.Optional[builtins.bool] = None,
-        response_headers_policy_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps, typing.Dict[str, typing.Any]]] = None,
+        response_headers_policy_props: typing.Optional[typing.Union[_aws_cdk_aws_cloudfront_ceddda9d.ResponseHeadersPolicyProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param existing_api_gateway_obj: Existing instance of api.RestApi object. Default: - None
@@ -290,26 +285,17 @@ class CloudFrontToApiGatewayProps:
         :summary: The properties for the CloudFrontToApiGateway Construct
         '''
         if isinstance(cloud_front_logging_bucket_props, dict):
-            cloud_front_logging_bucket_props = aws_cdk.aws_s3.BucketProps(**cloud_front_logging_bucket_props)
+            cloud_front_logging_bucket_props = _aws_cdk_aws_s3_ceddda9d.BucketProps(**cloud_front_logging_bucket_props)
         if isinstance(response_headers_policy_props, dict):
-            response_headers_policy_props = aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps(**response_headers_policy_props)
+            response_headers_policy_props = _aws_cdk_aws_cloudfront_ceddda9d.ResponseHeadersPolicyProps(**response_headers_policy_props)
         if __debug__:
-            def stub(
-                *,
-                existing_api_gateway_obj: aws_cdk.aws_apigateway.RestApi,
-                cloud_front_distribution_props: typing.Any = None,
-                cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                insert_http_security_headers: typing.Optional[builtins.bool] = None,
-                response_headers_policy_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__01cabecaad3c6de210af702ba75eda153a8ba6b2c9c87e9dd7eddf6561f6a8b3)
             check_type(argname="argument existing_api_gateway_obj", value=existing_api_gateway_obj, expected_type=type_hints["existing_api_gateway_obj"])
             check_type(argname="argument cloud_front_distribution_props", value=cloud_front_distribution_props, expected_type=type_hints["cloud_front_distribution_props"])
             check_type(argname="argument cloud_front_logging_bucket_props", value=cloud_front_logging_bucket_props, expected_type=type_hints["cloud_front_logging_bucket_props"])
             check_type(argname="argument insert_http_security_headers", value=insert_http_security_headers, expected_type=type_hints["insert_http_security_headers"])
             check_type(argname="argument response_headers_policy_props", value=response_headers_policy_props, expected_type=type_hints["response_headers_policy_props"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "existing_api_gateway_obj": existing_api_gateway_obj,
         }
         if cloud_front_distribution_props is not None:
@@ -322,14 +308,14 @@ class CloudFrontToApiGatewayProps:
             self._values["response_headers_policy_props"] = response_headers_policy_props
 
     @builtins.property
-    def existing_api_gateway_obj(self) -> aws_cdk.aws_apigateway.RestApi:
+    def existing_api_gateway_obj(self) -> _aws_cdk_aws_apigateway_ceddda9d.RestApi:
         '''Existing instance of api.RestApi object.
 
         :default: - None
         '''
         result = self._values.get("existing_api_gateway_obj")
         assert result is not None, "Required property 'existing_api_gateway_obj' is missing"
-        return typing.cast(aws_cdk.aws_apigateway.RestApi, result)
+        return typing.cast(_aws_cdk_aws_apigateway_ceddda9d.RestApi, result)
 
     @builtins.property
     def cloud_front_distribution_props(self) -> typing.Any:
@@ -343,13 +329,13 @@ class CloudFrontToApiGatewayProps:
     @builtins.property
     def cloud_front_logging_bucket_props(
         self,
-    ) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
+    ) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketProps]:
         '''Optional user provided props to override the default props for the CloudFront Logging Bucket.
 
         :default: - Default props are used
         '''
         result = self._values.get("cloud_front_logging_bucket_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.BucketProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketProps], result)
 
     @builtins.property
     def insert_http_security_headers(self) -> typing.Optional[builtins.bool]:
@@ -366,7 +352,7 @@ class CloudFrontToApiGatewayProps:
     @builtins.property
     def response_headers_policy_props(
         self,
-    ) -> typing.Optional[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps]:
+    ) -> typing.Optional[_aws_cdk_aws_cloudfront_ceddda9d.ResponseHeadersPolicyProps]:
         '''Optional user provided configuration that cloudfront applies to all http responses.
 
         Can be used to pass a custom ResponseSecurityHeadersBehavior, ResponseCustomHeadersBehavior or
@@ -379,7 +365,7 @@ class CloudFrontToApiGatewayProps:
         :default: - undefined
         '''
         result = self._values.get("response_headers_policy_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_cloudfront_ceddda9d.ResponseHeadersPolicyProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -399,3 +385,27 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__8b39051c9d03e4d1bc82ea6c294d254a848b0b34ee4e5d9d8323f095a78312d0(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    existing_api_gateway_obj: _aws_cdk_aws_apigateway_ceddda9d.RestApi,
+    cloud_front_distribution_props: typing.Any = None,
+    cloud_front_logging_bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    insert_http_security_headers: typing.Optional[builtins.bool] = None,
+    response_headers_policy_props: typing.Optional[typing.Union[_aws_cdk_aws_cloudfront_ceddda9d.ResponseHeadersPolicyProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__01cabecaad3c6de210af702ba75eda153a8ba6b2c9c87e9dd7eddf6561f6a8b3(
+    *,
+    existing_api_gateway_obj: _aws_cdk_aws_apigateway_ceddda9d.RestApi,
+    cloud_front_distribution_props: typing.Any = None,
+    cloud_front_logging_bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    insert_http_security_headers: typing.Optional[builtins.bool] = None,
+    response_headers_policy_props: typing.Optional[typing.Union[_aws_cdk_aws_cloudfront_ceddda9d.ResponseHeadersPolicyProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
